@@ -17,7 +17,7 @@
   <http://www.gnu.org/licenses/>
 */
 /**
- * @file lib/testing_api_cmd_backup_download.c
+ * @file testing/testing_api_cmd_backup_download.c
  * @brief command to download data to the sync backend service.
  * @author Christian Grothoff
  */
@@ -149,27 +149,24 @@ backup_download_run (void *cls,
       return;
     }
     if (GNUNET_OK !=
-        SYNC_TESTING_get_trait_hash (upload_cmd,
-                                     SYNC_TESTING_TRAIT_HASH_CURRENT,
-                                     &bds->upload_hash))
+        TALER_TESTING_get_trait_curr_hash (upload_cmd,
+                                           &bds->upload_hash))
     {
       GNUNET_break (0);
       TALER_TESTING_interpreter_fail (bds->is);
       return;
     }
     if (GNUNET_OK !=
-        SYNC_TESTING_get_trait_hash (upload_cmd,
-                                     SYNC_TESTING_TRAIT_HASH_PREVIOUS,
-                                     &bds->prev_upload_hash))
+        TALER_TESTING_get_trait_prev_hash (upload_cmd,
+                                           &bds->prev_upload_hash))
     {
       GNUNET_break (0);
       TALER_TESTING_interpreter_fail (bds->is);
       return;
     }
     if (GNUNET_OK !=
-        SYNC_TESTING_get_trait_account_pub (upload_cmd,
-                                            0,
-                                            &sync_pub))
+        TALER_TESTING_get_trait_account_pub (upload_cmd,
+                                             &sync_pub))
     {
       GNUNET_break (0);
       TALER_TESTING_interpreter_fail (bds->is);
