@@ -17,7 +17,7 @@
   <http://www.gnu.org/licenses/>
 */
 /**
- * @file lib/testing_api_cmd_backup_upload.c
+ * @file testing/testing_api_cmd_backup_upload.c
  * @brief command to upload data to the sync backend service.
  * @author Christian Grothoff
  */
@@ -189,9 +189,8 @@ backup_upload_cb (void *cls,
               bus->last_upload);
       GNUNET_assert (NULL != ref);
       GNUNET_assert (GNUNET_OK ==
-                     SYNC_TESTING_get_trait_hash (ref,
-                                                  SYNC_TESTING_TRAIT_HASH_CURRENT,
-                                                  &h));
+                     TALER_TESTING_get_trait_curr_hash (ref,
+                                                        &h));
       if (0 != GNUNET_memcmp (h,
                               &ud->details.recovered_backup.
                               existing_backup_hash))
@@ -248,9 +247,8 @@ backup_upload_run (void *cls,
       const struct GNUNET_HashCode *h;
 
       if (GNUNET_OK ==
-          SYNC_TESTING_get_trait_hash (ref,
-                                       SYNC_TESTING_TRAIT_HASH_CURRENT,
-                                       &h))
+          TALER_TESTING_get_trait_curr_hash (ref,
+                                             &h))
       {
         bus->prev_hash = *h;
       }
@@ -259,9 +257,8 @@ backup_upload_run (void *cls,
       const struct SYNC_AccountPrivateKeyP *priv;
 
       if (GNUNET_OK !=
-          SYNC_TESTING_get_trait_account_priv (ref,
-                                               0,
-                                               &priv))
+          TALER_TESTING_get_trait_account_priv (ref,
+                                                &priv))
       {
         GNUNET_break (0);
         TALER_TESTING_interpreter_fail (bus->is);
@@ -273,9 +270,8 @@ backup_upload_run (void *cls,
       const struct SYNC_AccountPublicKeyP *pub;
 
       if (GNUNET_OK !=
-          SYNC_TESTING_get_trait_account_pub (ref,
-                                              0,
-                                              &pub))
+          TALER_TESTING_get_trait_account_pub (ref,
+                                               &pub))
       {
         GNUNET_break (0);
         TALER_TESTING_interpreter_fail (bus->is);
@@ -373,7 +369,7 @@ backup_upload_cleanup (void *cls,
  * Offer internal data to other commands.
  *
  * @param cls closure
- * @param ret[out] result (could be anything)
+ * @param[out] ret result (could be anything)
  * @param trait name of the trait
  * @param index index number of the object to extract.
  * @return #GNUNET_OK on success
@@ -386,24 +382,18 @@ backup_upload_traits (void *cls,
 {
   struct BackupUploadState *bus = cls;
   struct TALER_TESTING_Trait straits[] = {
-    SYNC_TESTING_make_trait_hash (SYNC_TESTING_TRAIT_HASH_CURRENT,
-                                  &bus->curr_hash),
-    SYNC_TESTING_make_trait_hash (SYNC_TESTING_TRAIT_HASH_PREVIOUS,
-                                  &bus->prev_hash),
+    TALER_TESTING_make_trait_curr_hash (&bus->curr_hash),
+    TALER_TESTING_make_trait_prev_hash (&bus->prev_hash),
     TALER_TESTING_make_trait_claim_token (&bus->token),
-    SYNC_TESTING_make_trait_account_pub (0,
-                                         &bus->sync_pub),
-    SYNC_TESTING_make_trait_account_priv (0,
-                                          &bus->sync_priv),
+    TALER_TESTING_make_trait_account_pub (&bus->sync_pub),
+    TALER_TESTING_make_trait_account_priv (&bus->sync_priv),
     TALER_TESTING_make_trait_order_id (bus->payment_order_id),
     TALER_TESTING_trait_end ()
   };
   struct TALER_TESTING_Trait ftraits[] = {
     TALER_TESTING_make_trait_claim_token (&bus->token),
-    SYNC_TESTING_make_trait_account_pub (0,
-                                         &bus->sync_pub),
-    SYNC_TESTING_make_trait_account_priv (0,
-                                          &bus->sync_priv),
+    TALER_TESTING_make_trait_account_pub (&bus->sync_pub),
+    TALER_TESTING_make_trait_account_priv (&bus->sync_priv),
     TALER_TESTING_make_trait_order_id (bus->payment_order_id),
     TALER_TESTING_trait_end ()
   };
